<?php
// Copyright 1999-2024. WebPros International GmbH. All rights reserved.

namespace WHMCS\Module\Server\SolusVm2Vps\SolusAPI\Requests;

use WHMCS\Module\Server\SolusVm2Vps\Database\Models\ProductConfigOption;
use WHMCS\Module\Server\SolusVm2Vps\Helpers\Arr;
use WHMCS\Module\Server\SolusVm2Vps\WhmcsAPI\Product;

class CustomPlanData
{
    public static function fromModuleParams(array $moduleParams): ?array
    {
        $customPlanData = [];

        if ($vcpu = ConfigOptionExtractor::extractFromModuleParams($moduleParams, ProductConfigOption::VCPU)) {
            $customPlanData['params']['vcpu'] = (int)$vcpu;
        }
        if ($ram = ConfigOptionExtractor::extractFromModuleParams($moduleParams, ProductConfigOption::MEMORY)) {
            $customPlanData['params']['ram'] = $ram * 1024 * 1024;
        }
        if ($disk = ConfigOptionExtractor::extractFromModuleParams($moduleParams, ProductConfigOption::DISK_SPACE)) {
            $customPlanData['params']['disk'] = (int)$disk;
        }
        if ($vcpuUnits = ConfigOptionExtractor::extractFromModuleParams($moduleParams, ProductConfigOption::VCPU_UNITS)) {
            $customPlanData['params']['vcpu_units'] = (int)$vcpuUnits;
        }
        if ($vcpuLimit = ConfigOptionExtractor::extractFromModuleParams($moduleParams, ProductConfigOption::VCPU_LIMIT)) {
            $customPlanData['params']['vcpu_limit'] = (int)$vcpuLimit;
        }
        if ($ioPriority = ConfigOptionExtractor::extractFromModuleParams($moduleParams, ProductConfigOption::IO_PRIORITY)) {
            $customPlanData['params']['io_priority'] = (int)$ioPriority;
        }
        if ($swap = ConfigOptionExtractor::extractFromModuleParams($moduleParams, ProductConfigOption::SWAP)) {
            $customPlanData['params']['swap'] = $swap * 1024 * 1024;
        }
        if ($totalTrafficLimitMonthly =
            ConfigOptionExtractor::extractFromModuleParams($moduleParams, ProductConfigOption::TOTAL_TRAFFIC_LIMIT_MONTHLY)
        ) {
            $customPlanData['limits']['network_total_traffic'] = [
                'limit' => (int)$totalTrafficLimitMonthly,
            ];
        }

        $backupConfigOption = ConfigOptionExtractor::extractFromModuleParams($moduleParams, ProductConfigOption::IS_BACKUPS_ENABLED);
        $backupProductOption = Arr::get($moduleParams, 'configoption6');
        if ($backupConfigOption !== null) {
            $customPlanData['is_backup_available'] = (bool)$backupConfigOption;
        } elseif ($backupProductOption === Product::ENABLED_IN_PRODUCT) {
            $customPlanData['is_backup_available'] = true;
        }

        $snapshotConfigOption = ConfigOptionExtractor::extractFromModuleParams($moduleParams, ProductConfigOption::ARE_SNAPSHOTS_ENABLED);
        $snapshotProductOption = Arr::get($moduleParams, 'configoption10');
        if ($snapshotConfigOption !== null) {
            $customPlanData['is_snapshots_enabled'] = (bool)$snapshotConfigOption;
        } elseif ($snapshotProductOption === Product::ENABLED_IN_PRODUCT) {
            $customPlanData['is_snapshots_enabled'] = true;
        }

        return count($customPlanData) > 0 ? $customPlanData : null;
    }
}
